Deploying
=========

There are many options for deploying a package repository with Quetz. You can deploy Quetz either locally for 
testing, on a production server or in the cloud. The process can be tailored to your needs and exisiting
infrastructure.

.. toctree::
   :maxdepth: 2

   configuration
   authenticators
   database
   migrations
   frontend
   workers
   nginx
